/**
 * Grunt tasks file for businesslounge WordPress Theme
 * Created by RT-Themes
 * http://rtthemes.com
 *
 * use 'grunt release' for production
 * use 'grunt watch' for sass development
 * 
 * do js min
 * do css min
 * do compass compile
 * do combine css
 * do combine js
 */

module.exports = function(grunt) {

  grunt.loadNpmTasks('grunt-contrib-cssmin');
  grunt.loadNpmTasks('grunt-compass-multiple');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-contrib-clean');
  grunt.loadNpmTasks('grunt-contrib-concat');
  grunt.loadNpmTasks('grunt-contrib-uglify');

  grunt.initConfig({

      //--------------------------
      // compass compile at multi threads.
      //--------------------------
      compassMultiple: {
        options : {
          javascriptsDir: 'businesslounge/js',
          imagesDir: 'businesslounge/images',
          sassDir: 'businesslounge/css/sass',
          cssDir: 'businesslounge/css',
          relativeAssets: true,
        },

        // Release
        release: {
          options: {
            environment: 'production', 
            outputStyle: 'expanded',
            multiple: [
              {
                // admin
                sassDir: 'businesslounge/rt-framework/admin/css/sass',
                cssDir: 'businesslounge/rt-framework/admin/css'
              },{
                // theme
                sassDir: 'businesslounge/css/sass',
                cssDir: 'businesslounge/css'
              }
            ],            
          }
        },

        // Debug
        debug: {
          options: {
            environment: 'development', 
            outputStyle: 'expanded',
            multiple: [
              {
                // admin
                sassDir: 'businesslounge/rt-framework/admin/css/sass',
                cssDir: 'businesslounge/rt-framework/admin/css'
              },{
                // theme
                sassDir: 'businesslounge/css/sass',
                cssDir: 'businesslounge/css'
              }
            ],            
          }
        } 

      },


      //--------------------------
      // css min
      //--------------------------
      cssmin: {
        all: {
          files: [{
            expand: true,
            cwd: 'businesslounge/css',
            src: ['*.css', '!*.min.css'],
            dest: 'businesslounge/css',
            ext: '.min.css'
          }]
        },  
        woo: {
          files: [{
            expand: true,
            cwd: 'businesslounge/css/woocommerce',
            src: ['*.css', '!*.min.css'],
            dest: 'businesslounge/css/woocommerce',
            ext: '.min.css'
          }]
        },          
        admin: {
          files: [{
            expand: true,
            cwd: 'businesslounge/rt-framework/admin/css',
            src: ['*.css', '!*.min.css'],
            dest: 'businesslounge/rt-framework/admin/css',
            ext: '.min.css'
          }]
        },                
       // combine: {
       //   files: {
       //     'businesslounge/css/app.min.css': ['businesslounge/css/!app.min.css','businesslounge/css/!*.css', 'businesslounge/css/*.min.css']
       //   }
       // }        
      },

      //--------------------------
      // concat 
      //--------------------------
      concat: {
        options: {
          separator: '',
        },
        work1: {
          src: [
                'businesslounge/css/bootstrap.min.css',
                'businesslounge/css/owl-carousel.min.css',
                'businesslounge/css/style.min.css', 
                'businesslounge/css/lightgallery.min.css'
              ],
          dest: 'businesslounge/css/app.min.css',
        },       
        extras: {
          src: [
                'businesslounge/js/pace.js',
                'businesslounge/js/modernizr.min.js',
                'businesslounge/js/imagesloaded.min.js',  
                'businesslounge/js/lightgallery-all.min.js',
                'businesslounge/js/isotope.pkgd.min.js',
                'businesslounge/js/owl.carousel.min.js',
                'businesslounge/js/customselect.min.js',
                'businesslounge/js/jflickrfeed.min.js',
                'businesslounge/js/bootstrap.min.js', 
                'businesslounge/js/placeholders.min.js',
                'businesslounge/js/jquery.vide.min.js',
                
                'businesslounge/js/waitforimages.min.js',
                'businesslounge/js/easy-pie-chart.min.js',
                'businesslounge/js/perfect-scrollbar.min.js',
                'businesslounge/js/countdown.min.js',
                'businesslounge/js/jquery.appear.min.js',


                'businesslounge/js/scripts.min.js',
          ],
          dest: 'businesslounge/js/app.min.js',
        },        

      },

      //--------------------------
      // clean 
      //--------------------------
      clean: {
        css: [  
                'businesslounge/**/.DS_Store',
                'businesslounge/css/bootstrap.css',
                'businesslounge/css/style.css', 
                'businesslounge/css/rtl.css', 
                'businesslounge/rt-framework/admin/css/admin.css',
                'businesslounge/css/woocommerce/woocommerce.css', 
                'businesslounge/css/woocommerce/woocommerce-rtl.css', 
              ]
      },

      //--------------------------
      // Uglify 
      //--------------------------
      uglify: {
        options: {
          preserveComments: 'some'
        },
        dist: {
            files : {
              'businesslounge/js/scripts.min.js' : 'businesslounge/js/scripts.js' 
            }   

        },
        admin: {
            files : {
              'businesslounge/rt-framework/admin/js/script.min.js' : 'businesslounge/rt-framework/admin/js/script.js',
              'businesslounge/rt-framework/admin/js/customizer.min.js' : 'businesslounge/rt-framework/admin/js/customizer.js',
              'businesslounge/rt-framework/admin/js/rt-skin-selector.min.js' : 'businesslounge/rt-framework/admin/js/rt-skin-selector.js',
              'businesslounge/rt-framework/admin/js/rt-font-control.min.js' : 'businesslounge/rt-framework/admin/js/rt-font-control.js',
              'businesslounge/rt-framework/admin/js/rt-color-control.min.js' : 'businesslounge/rt-framework/admin/js/rt-color-control.js', 
              'businesslounge/rt-framework/admin/js/editor_buttons.min.js' : 'businesslounge/rt-framework/admin/js/editor_buttons.js'
            }            
        }        
      },

      //--------------------------
      // watch
      //--------------------------
      watch: {
        dev: {
          files: [
            'businesslounge/rt-framework/admin/css/**/*.scss',
            'businesslounge/css/**/*.scss',
            '*.css',
            '!*.min.css'
          ],
          tasks: [
            'default'
          ]
        }    
      },
  });
 
  // Default Task
  grunt.registerTask('default', ['compassMultiple:debug']); 

  // Release Task
  grunt.registerTask('release', ['clean:css','compassMultiple:release','uglify','cssmin','concat']); 

};